@@ -20,8 +20,25 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-"""Easy-To-Use SystemVerilog Parser."""
+"""Easy-To-Use SystemVerilog Parser.
 
-from ._sv_parser import parse_sv, print_token
+Usage is simple. Parse your input with one of these methods:
 
-__all__ = ["parse_sv", "print_token"]
+* [sv_simpleparser.parse_file][]
+* [sv_simpleparser.parse_text][]
+
+You receive a [sv_simpleparser.File][] object holding all information.
+"""
+
+from .datamodel import File, Module, ModuleInstance, Param, Port
+from .parser import parse_file, parse_text
+
+__all__ = [
+    "File",
+    "Module",
+    "ModuleInstance",
+    "Param",
+    "Port",
+    "parse_file",
+    "parse_text",
+]
